@@ -2,14 +2,17 @@ import sys
 import time
 
 import uuid
+
 import six
 from six.moves.http_cookies import SimpleCookie, CookieError
 
+from more_itertools import consume
+
 import cherrypy
-from cherrypy._cpcompat import text_or_bytes, ntob
+from cherrypy._cpcompat import ntob
 from cherrypy import _cpreqbody
 from cherrypy._cperror import format_exc, bare_error
-from cherrypy.lib import httputil, file_generator, reprconf
+from cherrypy.lib import httputil, reprconf, encoding
 
 
 class Hook(object):
@@ -138,8 +141,8 @@ def hooks_namespace(k, v):
     # hookpoint per path (e.g. "hooks.before_handler.1").
     # Little-known fact you only get from reading source ;)
     hookpoint = k.split('.', 1)[0]
-    if isinstance(v, text_or_bytes):
-        v = cherrypy.lib.attributes(v)
+    if isinstance(v, six.string_types):
+        v = cherrypy.lib.reprconf.attributes(v)
     if not isinstance(v, Hook):
         v = Hook(v)
     cherrypy.serving.request.hooks[hookpoint].append(v)
@@ -771,9 +774,8 @@ class ResponseBody(object):
 
     """The body of the HTTP response (the response entity)."""
 
-    if six.PY3:
-        unicode_err = ('Page handlers MUST return bytes. Use tools.encode '
-                       'if you wish to return unicode.')
+    unicode_err = ('Page handlers MUST return bytes. Use tools.encode '
+                   'if you wish to return unicode.')
 
     def __get__(self, obj, objclass=None):
         if obj is None:
@@ -784,30 +786,14 @@ class ResponseBody(object):
 
     def __set__(self, obj, value):
         # Convert the given value to an iterable object.
-        if six.PY3 and isinstance(value, str):
+        if isinstance(value, six.text_type):
             raise ValueError(self.unicode_err)
-
-        if isinstance(value, text_or_bytes):
-            # strings get wrapped in a list because iterating over a single
-            # item list is much faster than iterating over every character
-            # in a long string.
-            if value:
-                value = [value]
-            else:
-                # [''] doesn't evaluate to False, so replace it with [].
-                value = []
-        elif six.PY3 and isinstance(value, list):
+        elif isinstance(value, list):
             # every item in a list must be bytes...
-            for i, item in enumerate(value):
-                if isinstance(item, str):
-                    raise ValueError(self.unicode_err)
-        # Don't use isinstance here; io.IOBase which has an ABC takes
-        # 1000 times as long as, say, isinstance(value, str)
-        elif hasattr(value, 'read'):
-            value = file_generator(value)
-        elif value is None:
-            value = []
-        obj._body = value
+            if any(isinstance(item, six.text_type) for item in value):
+                raise ValueError(self.unicode_err)
+
+        obj._body = encoding.prepare_iter(value)
 
 
 class Response(object):
@@ -865,19 +851,17 @@ class Response(object):
 
     def collapse_body(self):
         """Collapse self.body to a single string; replace it and return it."""
-        if isinstance(self.body, text_or_bytes):
-            return self.body
+        new_body = b''.join(self.body)
+        self.body = new_body
+        return new_body
 
-        newbody = []
-        for chunk in self.body:
-            if six.PY3 and not isinstance(chunk, bytes):
-                raise TypeError("Chunk %s is not of type 'bytes'." %
-                                repr(chunk))
-            newbody.append(chunk)
-        newbody = b''.join(newbody)
-
-        self.body = newbody
-        return newbody
+    def _flush_body(self):
+        """
+        Discard self.body but consume any generator such that
+        any finalization can occur, such as is required by
+        caching.tee_output().
+        """
+        consume(iter(self.body))
 
     def finalize(self):
         """Transform headers (and cookies) into self.header_list. (Core)"""
@@ -903,6 +887,7 @@ class Response(object):
             # and 304 (not modified) responses MUST NOT
             # include a message-body."
             dict.pop(headers, 'Content-Length', None)
+            self._flush_body()
             self.body = b''
         else:
             # Responses which are not streamed should have a Content-Length,
