@@ -2,6 +2,7 @@
 
 import sys
 import time
+from uuid import UUID
 
 import six
 
@@ -46,7 +47,7 @@ class LogCase(object):
 
     logfile = None
     lastmarker = None
-    markerPrefix = ntob('test suite marker: ')
+    markerPrefix = b'test suite marker: '
 
     def _handleLogError(self, msg, data, marker, pattern):
         print('')
@@ -126,7 +127,7 @@ class LogCase(object):
         in_region = False
         for line in open(logfile, 'rb'):
             if in_region:
-                if (line.startswith(self.markerPrefix) and not marker in line):
+                if line.startswith(self.markerPrefix) and marker not in line:
                     break
                 else:
                     data.append(line)
@@ -161,6 +162,33 @@ class LogCase(object):
                 msg = '%r found in log' % line
                 self._handleLogError(msg, data, marker, line)
 
+    def assertValidUUIDv4(self, marker=None):
+        """Fail if the given UUIDv4 is not valid.
+
+        The log will be searched from the given marker to the next marker.
+        If marker is None, self.lastmarker is used. If the log hasn't
+        been marked (using self.markLog), the entire log will be searched.
+        """
+        data = self._read_marked_region(marker)
+        data = [
+            chunk.decode('utf-8').rstrip('\n').rstrip('\r')
+            for chunk in data
+        ]
+        for log_chunk in data:
+            try:
+                uuid_log = data[-1]
+                uuid_obj = UUID(uuid_log, version=4)
+            except (TypeError, ValueError):
+                pass  # it might be in other chunk
+            else:
+                if str(uuid_obj) == uuid_log:
+                    return
+                msg = '%r is not a valid UUIDv4' % uuid_log
+                self._handleLogError(msg, data, marker, log_chunk)
+
+        msg = 'UUIDv4 not found in log'
+        self._handleLogError(msg, data, marker, log_chunk)
+
     def assertLog(self, sliceargs, lines, marker=None):
         """Fail if log.readlines()[sliceargs] is not contained in 'lines'.
 
